@@ -40,11 +40,11 @@ __all__ = (
 
 class Object(Hashable):
     """代表一个通用的 QQ 对象。
-    这个类的目的是允许您创建数据类的 ``微型`` 版，让你只传入一个 ID。
+    这个类的目的是允许你创建数据类的 ``微型`` 版，让你只传入一个 ID。
     大多数接受带有 ID 的特定数据类的函数也可以接受这个类作为替代。
     请注意，即使是这种情况，并非所有对象（如果有）实际上都继承自此类。
     在某些情况下，某些 websocket 事件以奇怪的顺序接收，当发生此类事件时，
-    您将收到此类而不是实际的数据类。这些情况极为罕见。
+    你将收到此类而不是实际的数据类。这些情况极为罕见。
 
     .. container:: operations
 
